modulisto_flutter library

Modulisto flutter

Classes

ListenableAdapter
Wrapper around Unit that emulates Flutter SDK Listenable behavior
ListStore<T>
MapStore<K, V>
MapValueUnitView<T, F>
View of parent Store that listen for it updates and remaps value using mapper function
Module
ModuleScope<M extends Module>
A Flutter widget that provides a Module to its descendants.
ModulistoSettings
Mutable
MutatorContext
Notifier<T>
OperationPipelineLinker<T>
Pipeline
PipelineLinker<C, T>
Store<T>
A subtype of the Unit that represents a holder/storage/container for T value
StoreBuilder<T>
A Flutter widget that rebuilds when the given ValueUnit changes.
StreamPipelineLinker<T>
Trigger<T>
A subtype of the Unit that represents a unary (synchronous) call.
Unit<T>
UnitPipelineLinker<T>
ValueUnit<T>

Extension Types

UnitAdapter
Extendable adapter that allows you converter underlying unit into other several types (Stream, Listenable, etc)

Properties

eventTransformers → ({EventTransformer concurrent, EventTransformer droppable, EventTransformer restartable, EventTransformer sequental})
final

Typedefs

EventMapper<E> = Stream<E> Function(E value)
EventTransformer = Stream<E> Function<E>(Stream<E> source, EventMapper<E> process)
ModuleLifecycle = ({Unit<()> dispose, Unit<()> init})
PipelineRegisterCallback = void Function(PipelineRef on)
ValueChanged<T> = void Function(T value)
ValueMapper<T, F> = T Function(F value)