MapStore<K, V> class base

Inheritance
Implemented types

Constructors

MapStore(ModuleBase module, Map<K, V> initialValue, {String? debugName})

Properties

hashCode int
The hash code for this object.
no setterinherited
keys Iterable<K>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Map<K, V>
Currently stored value in this unit
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → V?