StreamPipelineLinker<T> class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bind(FutureOr<void> handler(MutatorContext context, T value))
→ void
-
Binds a notifies from
source into handler callback
Allow Store mutation via PipelineContext in handler
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
redirect(FutureOr<void> handler(T value))
→ void
-
Redirects payload from
source into handler callback
Doesn't allow Store mutations, since no PipelineContext provided
override
-
toString()
→ String
-
A string representation of this object.
inherited